# Services

```{eval-rst}
.. autoclass:: walnats.Services
    :members:
```

## D2 example

Here is a big working example of generating diagrams and its output.

```{literalinclude} ../examples/diagram.py
:language: python
```

The produced diagram:

![output](./schemas/arch.svg)
